@@ -2,7 +2,7 @@ package InfluxDB::LineProtocol;
 use strict;
 use warnings;
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 # ABSTRACT: Write and read InfluxDB LineProtocol
 
@@ -51,6 +51,39 @@ sub import {
 
 }
 
+sub _format_key {
+    my $k = shift;
+
+    $k =~ s/([, ])/\\$1/g;
+
+    return $k;
+}
+
+sub _format_value {
+    my $k = shift;
+    my $v = shift;
+
+    if ( $v =~ /^(-?\d+)(?:i?)$/ ) {
+        $v = $1 . 'i';
+    }
+    elsif ( $v =~ /^[Ff](?:ALSE|alse)?$/ ) {
+        $v = 'FALSE';
+    }
+    elsif ( $v =~ /^[Tt](?:RUE|rue)?$/ ) {
+        $v = 'TRUE';
+    }
+    elsif ( $v =~ /^-?\d+(?:\.\d+)?(?:e-?\d+)?$/ ) {
+        # pass it on, no mod
+    }
+    else {
+        # string actually, but this should be quoted differently?
+        $v =~ s/"/\\"/g;
+        $v = '"' . $v . '"';
+    }
+
+    return $v;
+}
+
 sub data2line {
     my ( $measurement, $values, $tags, $timestamp ) = @_;
     my $caller = caller();
@@ -72,6 +105,7 @@ sub data2line {
                 # TODO check if sorting algorithm matches
                 #      http://golang.org/pkg/bytes/#Compare
                 my $v = $tags->{$k};
+                next unless defined $v;
                 $k =~ s/([, ])/\\$1/g;
                 $v =~ s/([, ])/\\$1/g;
                 push( @tags, $k . '=' . $v );
@@ -93,23 +127,11 @@ sub data2line {
     my @fields;
     foreach my $k ( sort keys %$values ) {
         my $v = $values->{$k};
-        $k =~ s/([, ])/\\$1/g;
 
-        if (
-            # positive & negativ ints, exponentials, use Regexp::Common?
-            $v !~ /^-?\d+(?:\.\d+)?(?:e-?\d+)?$/
-            &&
-            # perl 5.12 Regexp::Assemble->new->add(qw(t T true TRUE f F false FALSE))->re;
-            $v !~ /^(?:F(?:ALSE)?|f(?:alse)?|T(?:RUE)?|t(?:rue)?)$/
-        )
-        {
-            $v =~ s/"/\\"/g;
-            $v = '"' . $v . '"';
-        }
-        elsif ($v=~/^-?\d+$/) { # looks like int
-            $v.='i';
-        }
-        push( @fields, $k . '=' . $v );
+        my $esc_k = _format_key($k);
+        my $esc_v = _format_value($k, $v);
+
+        push( @fields, $esc_k . '=' . $esc_v );
     }
     my $fields = join( ',', @fields );
 
@@ -237,7 +259,7 @@ sub _data2line_0_9_2 {
     my @fields;
     foreach my $k ( sort keys %$values ) {
         my $v = $values->{$k};
-        $k =~ s/([, ])/\\$1/g;
+        my $esc_k = _format_key($k);
 
         if (
             # positive & negativ ints, exponentials, use Regexp::Common?
@@ -250,7 +272,7 @@ sub _data2line_0_9_2 {
             $v =~ s/"/\\"/g;
             $v = '"' . $v . '"';
         }
-        push( @fields, $k . '=' . $v );
+        push( @fields, $esc_k . '=' . $v );
     }
     my $fields = join( ',', @fields );
 
@@ -312,7 +334,7 @@ InfluxDB::LineProtocol - Write and read InfluxDB LineProtocol
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =head1 SYNOPSIS
 
@@ -342,8 +364,8 @@ and tags work.
 
 C<InfluxDB::LineProtocol> will always try to implement the most
 current version of the InfluxDB line protocol, while allowing you to
-also get the old behaviour. Currently we support C<0.9.3> per default,
-and C<0.9.2> if you ask nicely.
+also get the old behaviour. Currently we support C<0.9.3> and newer
+per default, and C<0.9.2> if you ask nicely.
 
 =head2 FUNCTIONS
 
@@ -407,7 +429,7 @@ Currently supported version are:
 
 =over
 
-=item * 0.9.3
+=item * 0.9.3 and newer
 
 default, no need to specify anything
 
